aboutsummaryrefslogtreecommitdiffstats
path: root/components/script/dom/bindings/codegen/parser/tests/test_lenientSetter.py
diff options
context:
space:
mode:
Diffstat (limited to 'components/script/dom/bindings/codegen/parser/tests/test_lenientSetter.py')
-rw-r--r--components/script/dom/bindings/codegen/parser/tests/test_lenientSetter.py68
1 files changed, 47 insertions, 21 deletions
diff --git a/components/script/dom/bindings/codegen/parser/tests/test_lenientSetter.py b/components/script/dom/bindings/codegen/parser/tests/test_lenientSetter.py
index 78a9ffe9eaa..9d2230c3bec 100644
--- a/components/script/dom/bindings/codegen/parser/tests/test_lenientSetter.py
+++ b/components/script/dom/bindings/codegen/parser/tests/test_lenientSetter.py
@@ -2,8 +2,9 @@
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
+
def should_throw(parser, harness, message, code):
- parser = parser.reset();
+ parser = parser.reset()
threw = False
try:
parser.parse(code)
@@ -15,44 +16,69 @@ def should_throw(parser, harness, message, code):
def WebIDLTest(parser, harness):
- # The [LenientSetter] extended attribute MUST take no arguments.
- should_throw(parser, harness, "no arguments", """
+ # The [LegacyLenientSetter] extended attribute MUST take no arguments.
+ should_throw(
+ parser,
+ harness,
+ "no arguments",
+ """
interface I {
- [LenientSetter=X] readonly attribute long A;
+ [LegacyLenientSetter=X] readonly attribute long A;
};
- """)
+ """,
+ )
- # An attribute with the [LenientSetter] extended attribute MUST NOT
+ # An attribute with the [LegacyLenientSetter] extended attribute MUST NOT
# also be declared with the [PutForwards] extended attribute.
- should_throw(parser, harness, "PutForwards", """
+ should_throw(
+ parser,
+ harness,
+ "PutForwards",
+ """
interface I {
- [PutForwards=B, LenientSetter] readonly attribute J A;
+ [PutForwards=B, LegacyLenientSetter] readonly attribute J A;
};
interface J {
attribute long B;
};
- """)
+ """,
+ )
- # An attribute with the [LenientSetter] extended attribute MUST NOT
+ # An attribute with the [LegacyLenientSetter] extended attribute MUST NOT
# also be declared with the [Replaceable] extended attribute.
- should_throw(parser, harness, "Replaceable", """
+ should_throw(
+ parser,
+ harness,
+ "Replaceable",
+ """
interface I {
- [Replaceable, LenientSetter] readonly attribute J A;
+ [Replaceable, LegacyLenientSetter] readonly attribute J A;
};
- """)
+ """,
+ )
- # The [LenientSetter] extended attribute MUST NOT be used on an
+ # The [LegacyLenientSetter] extended attribute MUST NOT be used on an
# attribute that is not read only.
- should_throw(parser, harness, "writable attribute", """
+ should_throw(
+ parser,
+ harness,
+ "writable attribute",
+ """
interface I {
- [LenientSetter] attribute long A;
+ [LegacyLenientSetter] attribute long A;
};
- """)
+ """,
+ )
- # The [LenientSetter] extended attribute MUST NOT be used on a
+ # The [LegacyLenientSetter] extended attribute MUST NOT be used on a
# static attribute.
- should_throw(parser, harness, "static attribute", """
+ should_throw(
+ parser,
+ harness,
+ "static attribute",
+ """
interface I {
- [LenientSetter] static readonly attribute long A;
+ [LegacyLenientSetter] static readonly attribute long A;
};
- """)
+ """,
+ )